import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { html } from "lit-html";
import { withKnobs, text } from "@storybook/addon-knobs";
import CATEGORIES from "../categories";
import readme from "../../dist/docs/components/autosuggest-input/readme.md";

<Meta title={CATEGORIES.COMPONENTS + "Autosuggest Input"} />

# Autosuggest Input

This is a text input with Autosuggest - using an API. The responses are cached in JS for each query.
The example below uses static mock data, so the suggestions are always identical.

<Canvas
    mdxSource={`
    <ui-autosuggest-input
        label="Material Number"
        placeholder="123456789"
        url="/mock-data/autosuggest-orders.json"
    />
`}
>
    <Story
        height="310px"
        name="Autosuggest Input"
        parameters={{
            decorators: [withKnobs],
            jest: [
                "autosuggest-input.e2e.ts",
                "suggest-item.e2e.ts",
                "get-suggestion-highlight.spec.ts",
                "get-suggestions.spec.ts",
                "unique-id.spec.ts",
            ],
        }}
    >
        {html`
            <ui-autosuggest-input
                label="${text("label", "Material Number")}"
                placeholder="${text("placeholder", "123456789")}"
                url="${text("URL", "/mock-data/autosuggest-orders.json")}"
            />
        `}
    </Story>
</Canvas>

## Suggest Item

List Items in the suggestion dropdown. This component is used by ui-autosuggest-input internally.

<Canvas
    mdxSource={[1, 2, 3]
        .map(
            (i) =>
                `<ui-suggest-item text="123456789${i}" input="123" subline="Lorem ipsum dolor" image="https://www.trumpf.com/filestorage/TRUMPF_Master/_processed_/5/3/csm_TruLaser-Station-7000-product-picture_9d2558f917.jpg"/>`
        )
        .join("\n")}
>
    <Story
        height="230px"
        name="Suggest Item"
        parameters={{
            jest: ["suggest-item.e2e.ts", "get-suggestion-highlight.spec.ts"],
        }}
    >
        {html` ${[1, 2, 3].map(
            (i) => html`
                <ui-suggest-item
                    text="123456789${i}"
                    input="123"
                    subline="Lorem ipsum dolor"
                    image="https://www.trumpf.com/filestorage/TRUMPF_Master/_processed_/5/3/csm_TruLaser-Station-7000-product-picture_9d2558f917.jpg"
                />
            `
        )}`}
    </Story>
</Canvas>

## Suggest Item without image

When no image is supplied by the suggestion API it falls back to text only mode.

<Canvas
    mdxSource={[1, 2]
        .map(
            (i) =>
                `<ui-suggest-item text="123456789${i}" input="123" subline="Lorem ipsum dolor"/>`
        )
        .join("\n")}
>
    <Story height="160px" name="Suggest Item without image">
        {html` ${[1, 2].map(
            (i) => html`
                <ui-suggest-item
                    text="123456789${i}"
                    input="123"
                    subline="Lorem ipsum dolor"
                />
            `
        )}`}
    </Story>
</Canvas>

---

## Usage

```
<ui-autosuggest-input label="Autosuggest" placeholder="Enter Text" url="https://example.com/myapi"/>
```

# Developer Documentation

<Description markdown={readme} />
